Ponerinae_trait_tip_data: Dataset providing fake trait data for extant ponerine ants...

Ponerinae_trait_tip_dataR Documentation

Dataset providing fake trait data for extant ponerine ants for illustrative purposes

Description

A data.frame of fake trait data covering the 1534 extant ponerine ant taxa (Ponerinae subfamily). This is NOT real biological/ecological data. They were designed for illustrative purposes only.

Usage

data(Ponerinae_trait_tip_data)

Format

A data.frame with 1534 rows and 4 columns.

Details

A data.frame of fake trait data covering the 1534 extant ponerine ant taxa (Ponerinae subfamily).

  • ⁠$Taxa⁠ Character string. Names of ponerinae ant taxa.

  • ⁠$fake_cont_tip_data⁠ Numeric. Fake continuous trait data.

  • ⁠$fake_cat_2lvl_tip_data⁠ Vector of character strings. Fake categorical size data with two levels: "large" and "small".

  • ⁠$fake_cat_3lvl_tip_data⁠ Vector of character strings. Fake categorical habitat data with three levels: "arboreal", "subterranean", and "terricolous".


deepSTRAPP documentation built on Jan. 20, 2026, 1:06 a.m.